@@ -28,12 +28,13 @@
 
 #include <KIO/Global>
 #include <KLocalizedString>
-#include <KIconLoader>
 
+#include <QApplication>
 #include <QDBusConnection>
 #include <QMimeData>
 #include <QMimeDatabase>
 #include <QRegularExpression>
+#include <QStyle>
 #include <QUrl>
 
 using namespace Kerfuffle;
@@ -130,9 +131,9 @@ QVariant ArchiveModel::data(const QModelIndex &index, int role) const
         }
         case Qt::DecorationRole:
             if (index.column() == 0) {
-                const Archive::Entry *e = static_cast<Archive::Entry*>(index.internalPointer());
+                Archive::Entry *e = static_cast<Archive::Entry*>(index.internalPointer());
                 QIcon::Mode mode = (filesToMove.contains(e->fullPath())) ? QIcon::Disabled : QIcon::Normal;
-                return m_entryIcons.value(e->fullPath(NoTrailingSlash)).pixmap(IconSize(KIconLoader::Small), IconSize(KIconLoader::Small), mode);
+                return e->icon().pixmap(QApplication::style()->pixelMetric(QStyle::PM_SmallIconSize), mode);
             }
             return QVariant();
         case Qt::FontRole: {
@@ -155,7 +156,7 @@ Qt::ItemFlags ArchiveModel::flags(const QModelIndex &index) const
         return Qt::ItemIsEnabled | Qt::ItemIsSelectable | Qt::ItemIsDragEnabled | defaultFlags;
     }
 
-    return nullptr;
+    return Qt::NoItemFlags;
 }
 
 QVariant ArchiveModel::headerData(int section, Qt::Orientation, int role) const
@@ -340,7 +341,7 @@ QString ArchiveModel::cleanFileName(const QString& fileName)
 {
     // Skip entries with filename "/" or "//" or "."
     // "." is present in ISO files.
-    QRegularExpression pattern(QStringLiteral("/+|\\."));
+    static QRegularExpression pattern(QStringLiteral("/+|\\."));
     QRegularExpressionMatch match;
     if (fileName.contains(pattern, &match) && match.captured() == fileName) {
         qCDebug(ARK) << "Skipping entry with filename" << fileName;
@@ -360,7 +361,11 @@ void ArchiveModel::initRootEntry()
 
 Archive::Entry *ArchiveModel::parentFor(const Archive::Entry *entry, InsertBehaviour behaviour)
 {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     QStringList pieces = entry->fullPath().split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+    QStringList pieces = entry->fullPath().split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
     if (pieces.isEmpty()) {
         return nullptr;
     }
@@ -438,14 +443,17 @@ void ArchiveModel::slotEntryRemoved(const QString & path)
         return;
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     Archive::Entry *entry = m_rootEntry->findByPath(entryFileName.split(QLatin1Char('/'), QString::SkipEmptyParts));
+#else
+    Archive::Entry *entry = m_rootEntry->findByPath(entryFileName.split(QLatin1Char('/'), Qt::SkipEmptyParts));
+#endif
     if (entry) {
         Archive::Entry *parent = entry->getParent();
         QModelIndex index = indexForEntry(entry);
         Q_UNUSED(index);
 
         beginRemoveRows(indexForEntry(parent), entry->row(), entry->row());
-        m_entryIcons.remove(parent->entries().at(entry->row())->fullPath(NoTrailingSlash));
         parent->removeEntryAt(entry->row());
         endRemoveRows();
     }
@@ -536,7 +544,11 @@ void ArchiveModel::newEntry(Archive::Entry *receivedEntry, InsertBehaviour behav
     Archive::Entry *parent = parentFor(receivedEntry, behaviour);
 
     // Create an Archive::Entry.
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
     const QStringList path = entryFileName.split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+    const QStringList path = entryFileName.split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
     Archive::Entry *entry = parent->find(path.last());
     if (entry) {
         entry->copyMetaData(receivedEntry);
@@ -576,16 +588,6 @@ void ArchiveModel::insertEntry(Archive::Entry *entry, InsertBehaviour behaviour)
     if (behaviour == NotifyViews) {
         endInsertRows();
     }
-
-    // Save an icon for each newly added entry.
-    QMimeDatabase db;
-    QIcon icon;
-    entry->isDir()
-    ? icon = QIcon::fromTheme(db.mimeTypeForName(QStringLiteral("inode/directory")).iconName()).pixmap(IconSize(KIconLoader::Small),
-                                                                                                       IconSize(KIconLoader::Small))
-    : icon = QIcon::fromTheme(db.mimeTypeForFile(entry->fullPath()).iconName()).pixmap(IconSize(KIconLoader::Small),
-                                                                                       IconSize(KIconLoader::Small));
-    m_entryIcons.insert(entry->fullPath(NoTrailingSlash), icon);
 }
 
 Kerfuffle::Archive* ArchiveModel::archive() const
@@ -747,7 +749,11 @@ bool ArchiveModel::conflictingEntries(QList<const Archive::Entry*> &conflictingE
     // We can't accept destination as an argument, because it can be a new entry path for renaming.
     const Archive::Entry *destination;
     {
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         QStringList destinationParts = entries.first().split(QLatin1Char('/'), QString::SkipEmptyParts);
+#else
+        QStringList destinationParts = entries.first().split(QLatin1Char('/'), Qt::SkipEmptyParts);
+#endif
         destinationParts.removeLast();
         if (destinationParts.count() > 0) {
             destination = m_rootEntry->findByPath(destinationParts);
@@ -770,7 +776,11 @@ bool ArchiveModel::conflictingEntries(QList<const Archive::Entry*> &conflictingE
         }
 
         bool isDir = entry.right(1) == QLatin1String("/");
+#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         const Archive::Entry *archiveEntry = lastDirEntry->find(entry.split(QLatin1Char('/'), QString::SkipEmptyParts).last());
+#else
+        const Archive::Entry *archiveEntry = lastDirEntry->find(entry.split(QLatin1Char('/'), Qt::SkipEmptyParts).last());
+#endif
 
         if (archiveEntry != nullptr) {
             if (archiveEntry->isDir() != isDir || !allowMerging) {
@@ -820,11 +830,6 @@ QMap<QString, Archive::Entry*> ArchiveModel::entryMap(const QVector<Archive::Ent
     return map;
 }
 
-const QHash<QString, QIcon> ArchiveModel::entryIcons() const
-{
-    return m_entryIcons;
-}
-
 void ArchiveModel::slotCleanupEmptyDirs()
 {
     QList<QPersistentModelIndex> queue;
@@ -855,7 +860,6 @@ void ArchiveModel::slotCleanupEmptyDirs()
         Archive::Entry *rawEntry = static_cast<Archive::Entry*>(node.internalPointer());
         qCDebug(ARK) << "Delete with parent entries " << rawEntry->getParent()->entries() << " and row " << rawEntry->row();
         beginRemoveRows(parent(node), rawEntry->row(), rawEntry->row());
-        m_entryIcons.remove(rawEntry->getParent()->entries().at(rawEntry->row())->fullPath(NoTrailingSlash));
         rawEntry->getParent()->removeEntryAt(rawEntry->row());
         endRemoveRows();
     }
